#!/usr/bin/env python

import math

gms = 39.47841760
M_S = 1.989e30
M_E = 5.972e24

def Ss_func(a, m, m_cen):
    N = len(a)
    m_bar = sum(m)/N
    Ss = 6.0/(N-1.0) * (max(a)-min(a))/(max(a)+min(a)) * (3.0*m_cen/(2.0*m_bar))**(1.0/4.0)
    return Ss

def Sd_func(a, e, i, m):
    N = len(a)
    Sd = 0.0
    s = 0.0
    for j in xrange(0,N):
        Sd += m[j]*math.sqrt(a[j])*(1.0-math.sqrt(1.0-e[j]**2)*math.cos(i[j]))
        s += m[j]*math.sqrt(a[j])
    Sd /= s
    return Sd

def Sc_func(a, m):
    Scmax = 0.0
    N = 100
    M = len(a)
    for i in xrange(0,N):
        a_ = 0.2+1.8*i/N
        Sc = 0.0
        s = 0.0
        for j in xrange(0,M):
            Sc += m[j]*(math.log10(a_/a[j]))**2
            s += m[j]
        Sc = s/Sc
        if Sc > Scmax:
            Scmax = Sc
    return Scmax

def follow(filename, func):
    a = []
    e = []
    i = []
    m = []
    tlast = 0.0
    f = open(filename, "r")
    f2 = open("Ss.out", "w")
    f2.write("# t & N_pl & Ss [] & Sd [] & Sc []\n")
    for line in f.readlines():
        l = line.split()
        j = int(l[0])
        t = float(l[1])

        if t != tlast:
             Ss = Ss_func(a, m, gms)
             Sd = Sd_func(a, e, i, m)
             Sc = Sc_func(a, m)
             f2.write("%.8e	%d	%.4f	%.6f	%.6f\n" % (tlast, len(a), Ss, Sd, Sc))
             a = []
             e = []
             i = []
             m = []

        a.append(float(l[2]))
        e.append(float(l[3]))
        i.append(float(l[4]))
        m.append(float(l[8]))
        tlast = t

    f.close()
    return a, m

def main():
    follow("follow.out", Ss_func)

if __name__ == "__main__":
    main()

